@@ -5,7 +5,7 @@ knitr::opts_chunk$set(echo = TRUE)
 # devtools::install_github(c("ramnathv/htmlwidgets", "smartinsightsfromdata/rpivotTable"))
 
 ## ---- fig.show='hold'----------------------------------------------------
-library(rpivotTable)
+library(rpivotTable)  # No need to explicitly load htmlwidgets: this is done automatically
 
 ## ---- fig.show='hold'----------------------------------------------------
 data(mtcars)
@@ -26,7 +26,9 @@ if (attr == \"Hair\") { return sortAs([\"Red\", \"Brown\", \"Blond\", \"Black\"]
 }", width="100%", height="400px")
 
 ## ---- fig.show='hold'----------------------------------------------------
-suppressMessages(library(dplyr))
+# suppressMessages(
+  library(dplyr)
+  # )
 iris %>%
 tbl_df %>%
 filter( Sepal.Width > 3 & Sepal.Length > 5 ) %>%
